summaryrefslogtreecommitdiff
path: root/mpn/mips3/sub_n.s
diff options
context:
space:
mode:
Diffstat (limited to 'mpn/mips3/sub_n.s')
-rw-r--r--mpn/mips3/sub_n.s10
1 files changed, 5 insertions, 5 deletions
diff --git a/mpn/mips3/sub_n.s b/mpn/mips3/sub_n.s
index 56c77d8bc..366b3b014 100644
--- a/mpn/mips3/sub_n.s
+++ b/mpn/mips3/sub_n.s
@@ -1,4 +1,4 @@
# MIPS3 __mpn_sub_n -- Subtract two limb vectors of the same length > 0 and
# store difference in a third limb vector.
# Copyright (C) 1995 Free Software Foundation, Inc.
@@ -29,9 +29,9 @@
.text
.align 2
- .globl __mpn_sub_n
- .ent __mpn_sub_n
-__mpn_sub_n:
+ .globl __gmpn_sub_n
+ .ent __gmpn_sub_n
+__gmpn_sub_n:
.set noreorder
.set nomacro
@@ -117,4 +117,4 @@ __mpn_sub_n:
j $31
or $2,$2,$8
- .end __mpn_sub_n
+ .end __gmpn_sub_n
@@ -1,4 +1,4 @@
- # MIPS3 __mpn_sub_n -- Subtract two limb vectors of the same length > 0 and
+ # MIPS3 __gmpn_sub_n -- Subtract two limb vectors of the same length > 0 and
# store difference in a third limb vector.
# Copyright (C) 1995 Free Software Foundation, Inc.